==> haskell-optparse-simple-0.1.0-16-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-optparse-simple.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: optparse-simple
version: 0.1.0
id: optparse-simple-0.1.0-14tO0uZewYS9rh9lC4ayIa
key: optparse-simple-0.1.0-14tO0uZewYS9rh9lC4ayIa
license: BSD-3-Clause
copyright: 2015-2017 FP Complete
maintainer: chrisdone@fpcomplete.com
author: FP Complete
homepage: https://github.com/fpco/optparse-simple#readme
synopsis: Simple interface to optparse-applicative
description:
    Please see the README at <https://www.stackage.org/package/optparse-simple>
category: Options
abi: c1f6471ce941b46d681e7a6d8fa72c5c
exposed: True
exposed-modules:
    Options.Applicative.Simple
hidden-modules: Paths_optparse_simple
import-dirs: /usr/lib/ghc-8.4.3/site-local/optparse-simple-0.1.0
library-dirs: /usr/lib/ghc-8.4.3/site-local/optparse-simple-0.1.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/optparse-simple-0.1.0
hs-libraries: HSoptparse-simple-0.1.0-14tO0uZewYS9rh9lC4ayIa
depends:
    base-4.11.1.0 gitrev-1.3.1-I3rV26MPk8fH6eAgYo6ASC
    optparse-applicative-0.14.3.0-Lw3h8UUntos8R8YmnmFjNJ
    template-haskell-2.13.0.0 transformers-0.5.5.0
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             gitrev-1.3.1-I3rV26MPk8fH6eAgYo6ASC=dfadfabf13d3d9a6719171042287531b
             optparse-applicative-0.14.3.0-Lw3h8UUntos8R8YmnmFjNJ=82119580edadf24a95003dd94479a99c
             template-haskell-2.13.0.0=ac7dfd04924d4ebfa90a119ad22a36cc
             transformers-0.5.5.0=4f41484af13f560f1d83ed79e1be4572
haddock-interfaces: /usr/share/doc/haskell-optparse-simple/html/optparse-simple.haddock
haddock-html: /usr/share/doc/haskell-optparse-simple/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-optparse-simple-0.1.0-18-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-optparse-simple.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: optparse-simple
version: 0.1.0
id: optparse-simple-0.1.0-Lc8Rt7uTZ3wHwKqWy6FDQ3
key: optparse-simple-0.1.0-Lc8Rt7uTZ3wHwKqWy6FDQ3
license: BSD-3-Clause
copyright: 2015-2017 FP Complete
maintainer: chrisdone@fpcomplete.com
author: FP Complete
homepage: https://github.com/fpco/optparse-simple#readme
synopsis: Simple interface to optparse-applicative
description:
    Please see the README at <https://www.stackage.org/package/optparse-simple>
category: Options
abi: ed9f1b9051a55f987e11e00d145f7411
exposed: True
exposed-modules:
    Options.Applicative.Simple
hidden-modules: Paths_optparse_simple
import-dirs: /usr/lib/ghc-8.6.1/site-local/optparse-simple-0.1.0
library-dirs: /usr/lib/ghc-8.6.1/site-local/optparse-simple-0.1.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.6.1/optparse-simple-0.1.0
hs-libraries: HSoptparse-simple-0.1.0-Lc8Rt7uTZ3wHwKqWy6FDQ3
depends:
    base-4.12.0.0 gitrev-1.3.1-EQtKoLk36BRBfzqBgzf47p
    optparse-applicative-0.14.3.0-IKaF2mgRPI37cniOJkqr8k
    template-haskell-2.14.0.0 transformers-0.5.5.0
haddock-interfaces: /usr/share/doc/haskell-optparse-simple/html/optparse-simple.haddock
haddock-html: /usr/share/doc/haskell-optparse-simple/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
